Range-v3: ranges::v3::concepts::RandomAccessIota Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

All Classes Files Functions Variables Typedefs Modules Pages
Public Member Functions | List of all members
ranges::v3::concepts::RandomAccessIota Struct Reference
Inheritance diagram for ranges::v3::concepts::RandomAccessIota:

## Public Member Functions
template<typename T >
auto | requires_ (T t) -> decltype(concepts::valid_expr(concepts::model_of< Integral >(t-t), concepts::has_type< T & >(t+=(t-t)), concepts::has_type< T & >(t-=(t-t)), concepts::convertible_to< T >(t-(t-t)), concepts::convertible_to< T >(t+(t-t)), concepts::convertible_to< T >((t-t)+t)))
Public Member Functions inherited from ranges::v3::concepts::refines< BidirectionalIota >
void | requires_ (Ts &&...)

## Additional Inherited Members
Public Types inherited from ranges::v3::concepts::refines< BidirectionalIota >
using | base_concepts_t = meta::list< Concepts...>